-0.762 0.000 -1.009 -112

PSB is being developed by Pooya Paridel.
شاخص:1,363,939.01
(4065.71)
-0.3% - 18:59:11
(بورس) بسته - تعداد:396,773 حجم:
3.991 B
ارزش:
32,163.293 B
(فرابورس) بسته - تعداد:236,485 حجم:
2.571 B
ارزش:
681,276.235 B

آخرین معامله | 00/9/8 15:55:41

بازار بورس در یک نگاه

وضعیت بازار | بسته 18:59:11
شاخص کل | 1,363,939.01 (4065.71) -0.3%
ارزش بازار | 54,515,111.37 B
تعداد معاملات | 396,773
ارزش معاملات | 32,163.293 B
حجم معاملات | 3.991 B

بازار فرابورس در یک نگاه

وضعیت بازار | بسته 18:59:11
تعداد معاملات | 236,485
ارزش معاملات | 681,276.235 B
حجم معاملات | 2.571 B

بازار بورس - مشتقه در یک نگاه

وضعیت بازار | بسته 18:59:11
تعداد معاملات | 2,242
ارزش معاملات | 17.844 B
حجم معاملات | 7.82 M

شركت مديريت فناوري بورس تهران
Tehran Securities Exchange Technology Management Co
نماد
نام
تعداد
حجم
ارزش
دیروز
اولین
آخرین معامله
قیمت پایانی
کمترین
بیشترین
EPS
P/E
خرید
فروش
C0
C1
C2
مقدار
تغییر
درصد
مقدار
تغییر
درصد
تعداد
حجم
قیمت
قیمت
حجم
تعداد
ديرانح
ح . ‌ايران‌دارو
18
17,604
292,477,680
17,480
17,480
16,500
-980
-5.61
16,610
-870
-4.98
16,500
17,480
-
-
1
4,000
16,150
16,500
982,396
10
0
ورود

- اطلاعات نماد
- کلاس های خصوصی

امکان ساخت ستون جدید بر اساس فرمول شما فراهم شد. به راهنما مراجعه کنید.

اطلاعات سایقه تا 3 ماه قبل (60 روز معاملاتی) فراهم شد
امکان استفاده از تابع، حلقه، شرط و ... در فیلتر اضافه شد. به راهنما مراجعه کنید.
امکان استفاده از سابقه قیمت ها در ساخت فیلتر اضافه شد
امکان استفاده از اطلاعات حقیقی و حقوقی و آمارهای کلیدی در ساخت فیلتر اضافه شد
نام کلاس: برای انتخاب کلاس کلیک کنید
این بخش فعلا بصورت آزمایشی می باشد
ترتیب:نام (صعودی)
نمایش همه نمادها
fast_index
پیام جدید ناظر بازار x
وضعیت جدید نماد x
اطلاعیه جدید کدال x